@@ -50,7 +50,7 @@ class PDFLite(object):
         self.set_information()
         self.set_compression()
 
-    def set_compression(self, value=False):
+    def set_compression(self, value=True):
         # False is easier to read with a text editor.
         self.session._set_compression(value)
 
@@ -121,13 +121,6 @@ class PDFLite(object):
             output = None
         return output
 
-    # Font loading helpers
-    def load_fonts(self):
-        load_fonts.load_fonts()
-
-    def remove_fonts(self):
-        load_fonts.remove_fonts()
-
     # Private Methods for building the PDF
     def _put_header(self):
         " Standard first line in a PDF. "
